"""Unit tests for module fixed_shift_numpy"""

import numpy as np
import pytest

from lisainstrument.dynamic_delay_numpy import ShiftBC
from lisainstrument.fixed_shift_numpy import make_fixed_shift_lagrange_numpy


def test_fixed_shift_lagrange_dask() -> None:
    order = 5

    t, dt = np.linspace(-5.345, 10.345, 1003, retstep=True)

    def g(x):
        return (
            4.32546
            + 3.34324 * x
            - 4.342 * x**2
            - 0.46 * x**3
            + 1.43598 * x**4
            - 3.3456 * x**5
        )

    y = g(t)

    for d in (0.93456456 / dt, 3.1, 3.5, 3.9, 4.0, 4.1, 4.5, 4.9):

        op_np = make_fixed_shift_lagrange_numpy(ShiftBC.FLAT, ShiftBC.EXCEPTION, order)

        s_np = op_np(y, -d)
        s_ex = g(t - d * dt)

        margin_ex = -int(np.floor(-d)) + order // 2

        print(d, d * dt, margin_ex)

        assert s_ex[margin_ex:] == pytest.approx(s_np[margin_ex:], abs=1e-15, rel=5e-13)

        with pytest.raises(RuntimeError):
            op_np(y, d)

        op2_np = make_fixed_shift_lagrange_numpy(ShiftBC.EXCEPTION, ShiftBC.FLAT, order)

        s2_np = op2_np(y, d)
        s2_ex = g(t + d * dt)

        margin2_ex = int(np.floor(d)) + (order - order // 2)

        assert s2_ex[:-margin2_ex] == pytest.approx(
            s2_np[:-margin2_ex], abs=1e-15, rel=5e-13
        )

        with pytest.raises(RuntimeError):
            op2_np(y, -d)
