#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""Test the noises module."""


import pytest

from lisainstrument.noises import generate_random_seed, generate_subseed


def test_generate_random_seed() -> None:
    """Test the generate_random_seed function."""
    seed1 = generate_random_seed()
    seed2 = generate_random_seed()

    # Check that the seeds are within the valid range
    assert 0 <= seed1 < 2**32
    assert 0 <= seed2 < 2**32

    # Check that the seeds are not equal (highly unlikely to be the same)
    assert seed1 != seed2


def test_generate_subseed() -> None:
    """Test the generate_subseed function."""
    primary_seed = 12345
    name1 = "test1"
    name2 = "test2"

    subseed1 = generate_subseed(primary_seed, name1)
    subseed2 = generate_subseed(primary_seed, name2)
    subseed3 = generate_subseed(primary_seed, name1)

    # Check that the subseeds are within the valid range
    assert 0 <= subseed1 < 2**32
    assert 0 <= subseed2 < 2**32
    assert 0 <= subseed3 < 2**32

    # Check that different names produce different subseeds
    assert subseed1 != subseed2

    # Check that the same name produces the same subseed
    assert subseed1 == subseed3
